==> extension_libsoup-2.74.3.tar.xz: extension_libsoup-2.74.3/scripts/libsoup.sh <==
DESCRIPTION="The libsoup3 is a HTTP client/server library for GNOME."
# libsoup
# The libsoup3 is a HTTP client/server library for GNOME. It uses GObject and the GLib main loop to integrate with GNOME applications and it also has an asynchronous API for use in threaded applications. 

# Contents
# Installed Programs: None
# Installed Libraries: libsoup-3.0.so
# Installed DRI Driver Stubs: None
# Installed VA-API Drivers: None
# Installed GBM Backends: None
# Installed VDPAU Drivers: None
# Installed Vulkan Drivers: None
# Installed Directories: /usr/include/libsoup-3.0, /usr/share/doc/libsoup-3.6.4 (only installed if gi-docgen is available)

# Short Descriptions
# libsoup-3.0.so - provides functions for asynchronous HTTP connections

# Required
# None

# Recommended
# None

# Recommended_Runtime
# None

# Optional
# None

# Optional features and packages
# None

# Optional input plugins
# None

# Optional mux/demux plugins

# None

# Optional codec plugins
# None

# Optional video plugins
# None

# Optional audio plugins
# None

# Optional interface plugins
# None

# Optional visualisations and video filter plugins
# None

# Optional service discovery plugins
# None

# Miscellaneous options
# None

# Optional_Documentation
# None

# Optional_Testing
# None

EXT_VERSION=$(basename $PKG_LIBSOUP .tar.xz | cut -d "-" -f 2) 

mkdir build &&
cd    build &&

#[[ $(command -v gtkdocize) != "" ]] && OPTION="-D doc=enabled" || OPTION="-D doc=disabled"

meson setup --prefix=/usr       \
            --buildtype=release \
            -D vapi=enabled     \
            -D gssapi=disabled  \
            -D sysprof=disabled \
			$OPTION				\
            ..                  
ninja

# As root:
ninja install

update_version_list $PKG_LIBSOUP

==> extension_libsoup-3.6.4.tar.xz: extension_libsoup-3.6.4/scripts/libsoup.sh <==
DESCRIPTION="The libsoup3 is a HTTP client/server library for GNOME."
# libsoup
# The libsoup3 is a HTTP client/server library for GNOME. It uses GObject and the GLib main loop to integrate with GNOME applications and it also has an asynchronous API for use in threaded applications. 

# Contents
# Installed Programs: None
# Installed Libraries: libsoup-3.0.so
# Installed DRI Driver Stubs: None
# Installed VA-API Drivers: None
# Installed GBM Backends: None
# Installed VDPAU Drivers: None
# Installed Vulkan Drivers: None
# Installed Directories: /usr/include/libsoup-3.0, /usr/share/doc/libsoup-3.6.4 (only installed if gi-docgen is available)

# Short Descriptions
# libsoup-3.0.so - provides functions for asynchronous HTTP connections

# Required
# None

# Recommended
# None

# Recommended_Runtime
# None

# Optional
# None

# Optional features and packages
# None

# Optional input plugins
# None

# Optional mux/demux plugins

# None

# Optional codec plugins
# None

# Optional video plugins
# None

# Optional audio plugins
# None

# Optional interface plugins
# None

# Optional visualisations and video filter plugins
# None

# Optional service discovery plugins
# None

# Miscellaneous options
# None

# Optional_Documentation
# None

# Optional_Testing
# None

EXT_VERSION=$(basename $PKG_LIBSOUP .tar.xz | cut -d "-" -f 2) 

sed 's/apiversion/soup_version/' -i docs/reference/meson.build

mkdir build
cd    build

[[ $(command -v gi-docgen) != "" ]] && OPTION="-D docs=enabled" || OPTION="-D docs=disabled"

meson setup --prefix=/usr          \
            --buildtype=release    \
            --wrap-mode=nofallback \
			$OPTION					\
            ..
ninja

# As root:
ninja install

update_version_list $PKG_LIBSOUP
